# `info.json`

| workflow | status |
| - | - |
| `info` | [![info](https://github.com/ese-msc-2021/irp-ns1321/actions/workflows/info.yml/badge.svg)](https://github.com/ese-msc-2021/irp-ns1321/actions/workflows/info.yml) |

In this directory, you can find `info.json`. It is pre-populated with the data we have on our records. Your responsibility is to **keep it up to date and modify it as soon as anything regarding your IRP changes**. For instance, if you and your supervisor decide to alter the title or there has been a change in your supervisory team, please make those changes in `info.json`. To confirm that your `info.json` was modified correctly, please **ensure the `info` workflow in GitHub Actions is passing** - workflow badge in the table above.
